SQLAlchemy 0.3 Documentation - module sqlalchemy.ext.proxy

# SQLAlchemy 0.3 Documentation

Multiple Pages | One Page
Version: 0.3.7 Last Updated: 04/30/07 00:08:52

### module sqlalchemy.ext.proxy

### class AutoConnectEngine(BaseProxyEngine)

An SQLEngine proxy that automatically connects when necessary.

def __init__(self, dburi, **kwargs)
def get_engine(self)
back to section top

### class BaseProxyEngine(Executor)

Basis for all proxy engines.

def compiler(self, *args, **kwargs)

Override superclass behaviour.

This method is required to be present as it overrides the compiler method present in `sql.Engine`.

engine = property()
def execute_compiled(self, *args, **kwargs)

Override superclass behaviour.

This method is required to be present as it overrides the execute_compiled present in `sql.Engine`.

def get_engine(self)
def set_engine(self, engine)
back to section top

### class ProxyEngine(BaseProxyEngine)

Engine proxy for lazy and late initialization.

This engine will delegate access to a real engine set with connect().

def __init__(self, **kwargs)
def connect(self, *args, **kwargs)

Establish connection to a real engine.

def get_engine(self)
def set_engine(self, engine)
back to section top